This class represents a scalar axis. Its single value can be of any type. It is typically used as an auxiliary axis to record some parameter of interest such as the single time associated with a spatial grid with longitude, latitude and vertical axes.
ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisScalar
valueThe value of the axis. This could be a composite value, such
as a CFTime instance.
friendlyClassName(read-only) A nice description of the class.
dimnames(read-only) The coordinate of the axis.
new()Create an instance of this class.
CFAxisScalar$new(grp, nc_var, orientation, value)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
orientationThe orientation of this axis, or "" if not known.
valueThe value of this axis, possibly a compound type like
CFTime.
...Ignored.
self, invisibly.
brief()Some details of the axis.
CFAxisScalar$brief()A 1-row data.frame with some details of the axis.
sub_axis()Return the axis. This method returns a clone of this axis, given that a scalar axis cannot be subset.
CFAxisScalar$sub_axis(group, rng = NULL)groupThe group to create the new axis in.
rngIgnored.
A CFAxisScalar cloned from this axis.
clone()The objects of this class are cloneable with this method.
CFAxisScalar$clone(deep = FALSE)deepWhether to make a deep clone.