Learn R Programming

ncdfCF (version 0.2.1)

MemoryGroup: CF group in memory

Description

This class represents a CF group in memory. It descends from NCGroup and functions as such with the exception that it has no associated CFResource and the handle field thus always returns NULL.

Arguments

Super classes

ncdfCF::NCObject -> ncdfCF::NCGroup -> MemoryGroup

Active bindings

friendlyClassName

(read-only) A nice description of the class.

handle

Return NULL as a MemoryGroup has no resource.

Methods

Inherited methods


Method new()

Create an instance of this class.

Usage

MemoryGroup$new(id, name, fullname, parent, title, history)

Arguments

id

The identifier of the group.

name

The name of the group.

fullname

The fully qualified name of the group.

parent

The parent group of this group. The parent of the root group is NULL.

title, history

Title and history attributes for the group.


Method clone()

The objects of this class are cloneable with this method.

Usage

MemoryGroup$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

This object descends from NCGroup and functions as such with the exception that it has no associated CFResource and the handle field thus always returns NULL.