Learn R Programming

ncdfCF (version 0.2.1)

NCDimension: NetCDF dimension object

Description

This class represents an netCDF dimensions. It contains the information on a dimension that is stored in an netCDF file.

Arguments

Super class

ncdfCF::NCObject -> NCDimension

Public fields

length

The length of the dimension. If field unlim = TRUE, this field indicates the length of the data in this dimension written to file.

unlim

Logical flag to indicate if the dimension is unlimited, i.e. that additional data may be written to file incrementing in this dimension. Create a new netCDF dimension

This class should not be instantiated directly, create CF objects instead. This class is instantiated when opening a netCDF resource.

Methods

Inherited methods


Method new()

Usage

NCDimension$new(id, name, length, unlim)

Arguments

id

Numeric identifier of the netCDF dimension.

name

Character string with the name of the netCDF dimension.

length

Length of the dimension.

unlim

Is the dimension unlimited?

Returns

A NCDimension instance.


Method shard()

Very concise information on the dimension

The information returned by this function is very concise and most useful when combined with similar information from other dimensions.

Usage

NCDimension$shard()

Returns

Character string with very basic dimension information.


Method clone()

The objects of this class are cloneable with this method.

Usage

NCDimension$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

This class is not very useful for interactive use. Use the CFAxis descendent classes instead.