This class is a basic ancestor to all classes that represent netCDF objects, specifically groups, dimensions, variables and the user-defined types in a netCDF file. More useful classes use this class as ancestor.
The fields in this class are common among all netCDF objects. In addition, this class manages the attributes for its descendent classes.
Active bindings
id(read-only) Retrieve the identifier of the netCDF object.
nameSet or retrieve the name of the NC object. The netCDF file must be open for writing to change the name.
attributes(read-only) Read the attributes of the object. When there are no attributes, an empty
data.framewill be returned.CFRegister CF object that uses this netCDF object, or retrieve the list of registered CF objects.
Methods
NCObject$new()
Create a new netCDF object. This class should not be instantiated directly, create descendant objects instead.
Usage
NCObject$new(id, name, attributes = data.frame())NCObject$print_attributes()
This function prints the attributes of the netCDF object to the console.
NCObject$attribute()
Retrieve an attribute of a NC object.
NCObject$write_attributes()
Write the attributes of this object to a netCDF file. This will retain existing attributes, update modified attributes, and delete and add missing attributes from the passed in argument.