Skip to contents

This function creates a new, empty data set in memory. You can add groups, data variables and attributes to this data set as appropriate. The data set can be saved with CFDataset$save(), if so desired.

Usage

create_ncdf()