Learn R Programming

ncdfCF (version 0.1.1)

ncdfDataset-class: ncdfDataset class

Description

This class represents a single NetCDF resource.

Arguments

Slots

resource

The ncdfResource instance that handles the NetCDF file.

keep_open

Logical flag to indicate if the resource should remain open for data access after the initial read of metadata.

vars

A list with the variables in the resource.

dims

A list holding all the dimension data.

format

A character string with the format of the NetCDF resource.

has_error

logical. Flag to indicate if there was an error opening the resource.