Learn R Programming

ncdfCF (version 0.1.1)

ncdfDimensionGenerics: Generics for ncdfCF dimensions

Description

These are generic method definitions with implementations in descendant classes. See ncdfDimensionNumeric, ncdfDimensionCharacter and ncdfDimensionTime help topics for details.

Usage

has_bounds(x)

axis(x)

Value

has_bounds() returns a logical to indicate if bounds have been set on the dimension. axis() returns a character to indicate which of axes "X", "Y", "Z", or "T" is associated with the dimension, if any.

Arguments

x

The ncdfCF dimension that the method operates on.