The 'dimension' is one of the key building blocks of a data set in an netCDF
resource. This class is specifically for dimensions that represent the "time"
dimension.
Arguments
Slots
values
The values of the positions along the dimension, as an instance
of S4 class 'CFtime'.