ncdfCF objectsThese are generic method definitions with implementations in descendant classes. Please see the help topics for the descendant classes.
shard(object)brief(object)
id(object)
name(object)
attribute(object, att)
show_attributes(object)
Various. Please see the documentation of the methods in descendant classes.
The ncdfCF object that the method operates on. This includes
datasets, variables, dimensions, and possible others including instances
of descendant classes.
Name of the attribute to look up.