Learn R Programming

ncdfCF (version 0.1.1)

show_attributes,ncdfObject-method: Print the attributes of the object to the console

Description

Print the attributes of the object to the console

Usage

# S4 method for ncdfObject
show_attributes(object)

Value

Nothing.

Arguments

object

ncdfObject whose attributes to print.

Examples

Run this code
fn <- system.file("extdata",
                  "pr_day_EC-Earth3-CC_ssp245_r1i1p1f1_gr_20240101-20241231_vncdfCF.nc",
                  package = "ncdfCF")
ds <- open_ncdf(fn)
show_attributes(ds[["pr"]])

Run the code above in your browser using DataLab