Learn R Programming

ncdfCF (version 0.2.1)

CFAxisCharacter: Find indices in the axis domain

Description

This class represent CF axes that use categorical character labels as coordinate values.

Arguments

Super classes

ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisCharacter

Public fields

values

The character labels of this axis.

Active bindings

friendlyClassName

(read-only) A nice description of the class.

dimnames

(read-only) The coordinates of the axis as a character vector.

Methods

Inherited methods


Method new()

Create a new instance of this class.

Usage

CFAxisCharacter$new(grp, nc_var, nc_dim, orientation, values)

Arguments

grp

The group that contains the netCDF variable.

nc_var

The netCDF variable that describes this instance.

nc_dim

The netCDF dimension that describes the dimensionality.

orientation

The orientation (X, Y, Z, or T) or "" if different or unknown.

values

The character dimension values of this axis.


Method brief()

Some details of the axis

Usage

CFAxisCharacter$brief()

Returns

A 1-row data.frame with some details of the axis.


Method indexOf()

Given a vector of character strings x, find their indices in the values of the axis.

Usage

CFAxisCharacter$indexOf(x, method = "constant")

Arguments

x

Vector of character strings to find axis indices for.

method

Ignored.

Returns

Numeric vector of the same length as x. Values of x outside of the range of the values in the axis are returned as NA.


Method clone()

The objects of this class are cloneable with this method.

Usage

CFAxisCharacter$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

CF character axis object