This class represent CF axes that use categorical character labels as coordinate values.
ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisCharacter
valuesThe character labels of this axis.
friendlyClassName(read-only) A nice description of the class.
dimnames(read-only) The coordinates of the axis as a character vector.
new()Create a new instance of this class.
CFAxisCharacter$new(grp, nc_var, nc_dim, orientation, values)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
nc_dimThe netCDF dimension that describes the dimensionality.
orientationThe orientation (X, Y, Z, or T) or "" if
different or unknown.
valuesThe character dimension values of this axis.
brief()Some details of the axis
CFAxisCharacter$brief()A 1-row data.frame with some details of the axis.
indexOf()Given a vector of character strings x, find their indices
in the values of the axis.
CFAxisCharacter$indexOf(x, method = "constant")xVector of character strings to find axis indices for.
methodIgnored.
Numeric vector of the same length as x. Values of x outside
of the range of the values in the axis are returned as NA.
clone()The objects of this class are cloneable with this method.
CFAxisCharacter$clone(deep = FALSE)deepWhether to make a deep clone.
CF character axis object