This class represent discrete CF axes, i.e. those axes whose coordinate values do not represent a physical or categorical property. The coordinate values are ordinal values equal to the index into the axis.
ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisDiscrete
friendlyClassName(read-only) A nice description of the class.
dimnames(read-only) The coordinates of the axis as an integer vector.
new()Create a new instance of this class.
CFAxisDiscrete$new(grp, nc_var, nc_dim, orientation)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
nc_dimThe netCDF dimension that describes the dimensionality.
orientationThe orientation (X, Y, Z, or T) or "" if
different or unknown.
brief()Some details of the axis
CFAxisDiscrete$brief()A 1-row data.frame with some details of the axis.
indexOf()Given a vector of numerical values x, find their indices
in the values of the axis. In effect, this returns index values into the
axis, but outside values will be dropped.
CFAxisDiscrete$indexOf(x, method = "constant")xVector of numeric values to find axis indices for.
methodIgnored.
Numeric vector of the same length as x. Values of x outside
of the range of the values in the axis are returned as 0 and
.Machine$integer.max, respectively.
clone()The objects of this class are cloneable with this method.
CFAxisDiscrete$clone(deep = FALSE)deepWhether to make a deep clone.
CF discrete axis object