This class represents a latitude axis. Its values are numeric. This class adds some logic that is specific to latitudes, such as their range, orientation and their meaning.
ncdfCF::CFObject -> ncdfCF::CFAxis -> ncdfCF::CFAxisNumeric -> CFAxisLatitude
friendlyClassName(read-only) A nice description of the class.
new()Create a new instance of this class.
CFAxisLatitude$new(grp, nc_var, nc_dim, values)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
nc_dimThe netCDF dimension that describes the dimensionality.
valuesThe dimension values of this axis.
sub_axis()Return an axis spanning a smaller dimension range.
This method returns an axis which spans the range of indices given by
the rng argument.
CFAxisLatitude$sub_axis(group, rng = NULL)groupThe group to create the new axis in.
rngThe range of values from this axis to include in the returned axis.
A CFAxisLatitude covering the indicated range of indices. If
the rng argument includes only a single value, an CFAxisScalar
instance is returned with the value from this axis. If the value of the
argument is NULL, return the entire axis (possibly as a scalar axis).
clone()The objects of this class are cloneable with this method.
CFAxisLatitude$clone(deep = FALSE)deepWhether to make a deep clone.