This class represents a longitude axis. Its values are numeric. This class is used for axes that represent longitudes.
This class adds some logic that is specific to longitudes, such as their range, orientation and their meaning. (In the near future, it will also support selecting data that crosses the 0-360 degree boundary.)
ncdfCF::CFObject -> ncdfCF::CFAxis -> ncdfCF::CFAxisNumeric -> CFAxisLongitude
friendlyClassName(read-only) A nice description of the class.
new()Create a new instance of this class.
CFAxisLongitude$new(grp, nc_var, nc_dim, values)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
nc_dimThe netCDF dimension that describes the dimensionality.
valuesThe dimension values of this axis.
sub_axis()Return an axis spanning a smaller dimension range.
This method returns an axis which spans the range of indices given by
the rng argument.
CFAxisLongitude$sub_axis(group, rng = NULL)groupThe group to create the new axis in.
rngThe range of values from this axis to include in the returned axis.
A CFAxisLongitude covering the indicated range of indices. If
the rng argument includes only a single value, an CFAxisScalar
instance is returned with the value from this axis. If the value of the
argument is NULL, return the entire axis (possibly as a scalar axis).
clone()The objects of this class are cloneable with this method.
CFAxisLongitude$clone(deep = FALSE)deepWhether to make a deep clone.