Learn R Programming

ncdfCF (version 0.2.1)

CFAxisScalar: Scalar CF axis object

Description

This class represents a scalar axis. Its single value can be of any type. It is typically used as an auxiliary axis to record some parameter of interest such as the single time associated with a spatial grid with longitude, latitude and vertical axes.

Arguments

Super classes

ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisScalar

Public fields

value

The value of the axis.

Active bindings

friendlyClassName

(read-only) A nice description of the class.

dimnames

(read-only) The coordinate of the axis.

Methods

Inherited methods


Method new()

Create an instance of this class.

Usage

CFAxisScalar$new(grp, nc_var, orientation, value)

Arguments

grp

The group that contains the netCDF variable.

nc_var

The netCDF variable that describes this instance.

orientation

The orientation of this axis, or "" if not known.

value

The value of this axis.


Method print()

Summary of the scalar axis

Prints a summary of the scalar axis to the console.

Usage

CFAxisScalar$print()


Method brief()

Retrieve a 1-row data.frame with some information on this axis.

Usage

CFAxisScalar$brief()


Method sub_axis()

Return the axis. This method returns a clone of this axis, given that a scalar axis cannot be subset.

Usage

CFAxisScalar$sub_axis(group, rng = NULL)

Arguments

group

The group to create the new axis in.

rng

Ignored.

Returns

A CFAxisScalar cloned from this axis.


Method clone()

The objects of this class are cloneable with this method.

Usage

CFAxisScalar$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.