This class represents a scalar axis. Its single value can be of any type. It is typically used as an auxiliary axis to record some parameter of interest such as the single time associated with a spatial grid with longitude, latitude and vertical axes.
ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisScalar
valueThe value of the axis.
friendlyClassName(read-only) A nice description of the class.
dimnames(read-only) The coordinate of the axis.
new()Create an instance of this class.
CFAxisScalar$new(grp, nc_var, orientation, value)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
orientationThe orientation of this axis, or "" if not known.
valueThe value of this axis.
print()Summary of the scalar axis
Prints a summary of the scalar axis to the console.
CFAxisScalar$print()
brief()Retrieve a 1-row data.frame with some information on this axis.
CFAxisScalar$brief()
sub_axis()Return the axis. This method returns a clone of this axis, given that a scalar axis cannot be subset.
CFAxisScalar$sub_axis(group, rng = NULL)groupThe group to create the new axis in.
rngIgnored.
A CFAxisScalar cloned from this axis.
clone()The objects of this class are cloneable with this method.
CFAxisScalar$clone(deep = FALSE)deepWhether to make a deep clone.