This class represents a time axis. The functionality is provided
by the CFtime package.
ncdfCF::CFObject -> ncdfCF::CFAxis -> CFAxisTime
valuesThe CFtime instance to manage CF time.
friendlyClassName(read-only) A nice description of the class.
dimnames(read-only) The coordinates of the axis as a character vector.
new()Create a new instance of this class.
CFAxisTime$new(grp, nc_var, nc_dim, values)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
nc_dimThe netCDF dimension that describes the dimensionality.
valuesThe CFtime instance that manages this axis.
print()Summary of the time axis
Prints a summary of the time axis to the console.
CFAxisTime$print()
brief()Retrieve a 1-row data.frame with some information on this axis.
CFAxisTime$brief()
indexOf()Retrieve the indices of supplied values on the time axis.
CFAxisTime$indexOf(x, method = "constant", rightmost.closed = FALSE)xA vector of timestamps whose indices into the time axis to extract.
methodExtract index values without ("constant", the default) or with ("linear") fractional parts.
rightmost.closedWhether or not to include the upper limit.
Default is FALSE.
An integer vector giving the indices in the time axis of valid
values in x, or integer(0) if none of the values are valid.
sub_axis()Return an axis spanning a smaller dimension range
This method returns an axis which spans the range of indices given by
the rng argument.
CFAxisTime$sub_axis(group, rng = NULL)groupThe group to create the new axis in.
rngThe range of values from this axis to include in the returned axis.
A CFAxisTime covering the indicated range of indices. If the
rng argument includes only a single value, an CFAxisScalar instance
is returned with its value being the character timestamp of the value
in this axis. If the value of the argument is NULL, return the entire
axis (possibly as a scalar axis).
clone()The objects of this class are cloneable with this method.
CFAxisTime$clone(deep = FALSE)deepWhether to make a deep clone.