Learn R Programming

ncdfCF (version 0.2.1)

CFBounds: CF bounds variable

Description

This class represents the bounds of an axis or an auxiliary longitude-latitude grid.

Arguments

Super class

ncdfCF::CFObject -> CFBounds

Public fields

values

A matrix with the bounds values.

Active bindings

friendlyClassName

(read-only) A nice description of the class.

Methods

Inherited methods


Method new()

Create an instance of this class.

Usage

CFBounds$new(nc_var, values)

Arguments

nc_var

The NC variable that describes this instance.

values

A matrix with the bounds values.


Method print()

Print a summary of the object to the console.

Usage

CFBounds$print()


Method range()

Retrieve the lowest and highest value in the bounds.

Usage

CFBounds$range()


Method sub_bounds()

Return bounds spanning a smaller dimension range.

This method returns bounds which spans the range of indices given by the rng argument.

Usage

CFBounds$sub_bounds(group, rng)

Arguments

group

The group to create the new bounds in.

rng

The range of values from this bounds object to include in the returned object.

Returns

A CFBounds instance covering the indicated range of indices.


Method clone()

The objects of this class are cloneable with this method.

Usage

CFBounds$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

The class manages the bounds information for an axis (2 vertices per element) or an auxiliary longitude-latitude grid (4 vertices per element).