This class represents the bounds of an axis or an auxiliary longitude-latitude grid.
ncdfCF::CFObject -> CFBounds
valuesA matrix with the bounds values.
friendlyClassName(read-only) A nice description of the class.
Inherited methods
new()Create an instance of this class.
CFBounds$new(nc_var, values)nc_varThe NC variable that describes this instance.
valuesA matrix with the bounds values.
sub_bounds()Return bounds spanning a smaller dimension range.
This method returns bounds which spans the range of indices given by
the rng argument.
CFBounds$sub_bounds(group, rng)groupThe group to create the new bounds in.
rngThe range of values from this bounds object to include in the returned object.
A CFBounds instance covering the indicated range of indices.
clone()The objects of this class are cloneable with this method.
CFBounds$clone(deep = FALSE)deepWhether to make a deep clone.
The class manages the bounds information for an axis (2 vertices per element) or an auxiliary longitude-latitude grid (4 vertices per element).