Learn R Programming

ncdfCF (version 0.2.1)

CFGridMapping: CF grid mapping object

Description

This class contains the details for a coordinate reference system, or grid mapping in CF terms, of a data variable.

Arguments

Super class

ncdfCF::CFObject -> CFGridMapping

Public fields

group

The NCGroup that this grid mapping is located in.

grid_mapping_name

The formal name of the grid mapping.

Active bindings

friendlyClassName

(read-only) A nice description of the class.

Methods

Inherited methods


Method new()

Create a new instance of this class.

Usage

CFGridMapping$new(grp, nc_var, name)

Arguments

grp

The group that contains the netCDF variable.

nc_var

The netCDF variable that describes this instance.

name

The formal grid mapping name from the attribute.


Method print()

Prints a summary of the grid mapping to the console.

Usage

CFGridMapping$print()


Method brief()

Retrieve a 1-row data.frame with some information on this grid mapping.

Usage

CFGridMapping$brief()


Method crs()

Retrieve the CRS string for a specific variable.

Usage

CFGridMapping$crs(axis_info)

Arguments

axis_info

A list with information that describes the axes of the CFVariable or CFData instance to describe.

Returns

A character string with the CRS in WKT2 format.


Method clone()

The objects of this class are cloneable with this method.

Usage

CFGridMapping$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.