This class contains the details for a coordinate reference system, or grid mapping in CF terms, of a data variable.
ncdfCF::CFObject -> CFGridMapping
groupThe NCGroup that this grid mapping is located in.
grid_mapping_nameThe formal name of the grid mapping.
friendlyClassName(read-only) A nice description of the class.
Inherited methods
new()Create a new instance of this class.
CFGridMapping$new(grp, nc_var, name)grpThe group that contains the netCDF variable.
nc_varThe netCDF variable that describes this instance.
nameThe formal grid mapping name from the attribute.
brief()Retrieve a 1-row data.frame with some information on this grid mapping.
CFGridMapping$brief()
crs()Retrieve the CRS string for a specific variable.
CFGridMapping$crs(axis_info)axis_infoA list with information that describes the axes of the
CFVariable or CFData instance to describe.
A character string with the CRS in WKT2 format.
clone()The objects of this class are cloneable with this method.
CFGridMapping$clone(deep = FALSE)deepWhether to make a deep clone.