This class is a basic ancestor to all classes that represent CF objects, specifically data variables and axes. More useful classes use this class as ancestor.
NCvarThe NCVariable instance that this CF object represents.
groupThe NCGroup that this object is located in.
friendlyClassName(read-only) A nice description of the class.
id(read-only) The identifier of the CF object.
name(read-only) The name of the CF object.
fullname(read-only) The fully-qualified name of the CF object.
attributes(read-only) A data.frame with the attributes of the
CF object.
new()Create a new CF object instance from a variable in a netCDF resource. This method is called upon opening a netCDF resource. It is rarely, if ever, useful to call this constructor directly from the console. Instead, use the methods from higher-level classes such as CFVariable.
CFObject$new(nc_var, group)nc_varThe NCVariable instance upon which this CF object is based.
groupThe NCGroup that this object is located in.
A CFobject instance.
attribute()Retrieve attributes of any CF object.
CFObject$attribute(att, field = "value")attVector of character strings of attributes to return.
fieldThe field of the data.frame to return values from. This
must be "value" (default), "type" or "length".
If the field argument is "type" or "length", a character vector
named with the att values that were found in the attributes. If
argument field is "value", a list with elements named with the att
values, containing the attribute value(s), except when argument att
names a single attribute, in which case that attribute value is
returned as a character string. If no attribute is named with a value
of argument att an empty list is returned, or an empty string if
there was only one value in argument att.
print_attributes()Print the attributes of the CF object to the console.
CFObject$print_attributes(width = 50L)widthThe maximum width of each column in the data.frame when
printed to the console.
clone()The objects of this class are cloneable with this method.
CFObject$clone(deep = FALSE)deepWhether to make a deep clone.