This class is a basic ancestor to all classes that represent CF objects, specifically data variables and axes. More useful classes use this class as ancestor.
NCvarThe NCVariable instance that this CF object represents.
friendlyClassName(read-only) A nice description of the class.
id(read-only) The identifier of the CF object.
name(read-only) The name of the CF object.
attributes(read-only) A data.frame with the attributes of the CF object.
new()Create a new CF object instance from a variable in a netCDF resource. This method is called upon opening a netCDF resource. It is rarely, if ever, useful to call this constructor directly from the console. Instead, use the methods from higher-level classes such as CFVariable.
CFObject$new(nc_var)nc_varThe NCVariable instance upon which this CF object is based.
A CFobject instance.
attribute()Retrieve attributes of any CF object.
CFObject$attribute(att, field = "value")attVector of character strings of attributes to return.
fieldThe field of the data.frame to return values from. This
must be "value" (default), "type" or "length".
A vector of values from the data.frame, named with the att
value, character(0) if a name in att is not an attribute of this
object.
print_attributes()Print the attributes of the CF object.
CFObject$print_attributes(width = 50)widthThe maximum width of each column in the data.frame when
printed to the console.
clone()The objects of this class are cloneable with this method.
CFObject$clone(deep = FALSE)deepWhether to make a deep clone.
The fields in this class are common among all CF objects.