This class contains the connection details to the netCDF resource.
errorError message, or empty string. Create a netCDF resource
This is called when opening a netCDF resource. You should never have to call this directly.
friendlyClassName(read-only) A nice description of the class.
handleThe handle to the netCDF resource.
uriThe URI of the netCDF resource, either a local filename or the location of an online resource.
new()CFResource$new(uri)uriThe URI of the netCDF resource.
An instance of this class.
finalize()Clean up open resources
This method is called automatically when the instance is deleted, ensuring that file handles are properly closed.
CFResource$finalize()
close()Close an open resource
Closing an open netCDF resource. It should rarely be necessary to call this method directly. Get the netCDF handle to a group
Every group in a netCDF file has its own handle. The handle returned by this method is valid only for the named group.
CFResource$close()
group_handle()CFResource$group_handle(group_name)group_nameThe absolute path to the group.
The handle to the group
clone()The objects of this class are cloneable with this method.
CFResource$clone(deep = FALSE)deepWhether to make a deep clone.
There is a single instance for every netCDF resource, owned by the CFDataset instance. The instance is shared by other objects, specifically NCGroup and CFVariable instances, for access to the underlying resource for reading of data.