This class represents the basic structure of a CF data variable, the object that provides access to an array of data.
The CF data variable instance provides access to the data array from the netCDF resource, as well as all the details that have been associated with the data variable, such as axis information, grid mapping parameters, etc.
Do not use this class directly. Instead, use CFVariableGeneric of any of
the more specific CFVariable* classes.
ncdfCF::CFObject -> CFVariable
axesList of instances of classes descending from CFAxis that are the axes of the variable.
grid_mappingThe coordinate reference system of this variable, as
an instance of CFGridMapping. If this field is NULL, the horizontal
component of the axes are in decimal degrees of longitude and latitude.
friendlyClassName(read-only) A nice description of the class.
gridLongLatThe grid of longitude and latitude values of every grid cell when the main variable grid has a different coordinate system.
crs(read-only) Retrieve the coordinate reference system description of the variable as a WKT2 string.
Inherited methods
new()Create an instance of this class.
CFVariable$new(grp, nc_var, axes)grpThe group that this CF variable lives in.
nc_varThe netCDF variable that defines this CF variable.
axesList of CFAxis instances that describe the dimensions.
An instance of this class.
brief()Some details of the data variable.
CFVariable$brief()A 1-row data.frame with some details of the data variable.
shard()The information returned by this method is very concise and most useful when combined with similar information from other variables.
CFVariable$shard()Character string with very basic variable information.
peek()Retrieve interesting details of the data variable.
CFVariable$peek(with_groups = TRUE)with_groupsShould group information be included? The save option
is TRUE (default) when the netCDF resource has groups because names may
be duplicated among objects in different groups.
A 1-row data.frame with details of the data variable.
data()Retrieve all data of the variable. Scalar variables are not present in the result.
CFVariable$data()A CFData instance with all data from this variable.
clone()The objects of this class are cloneable with this method.
CFVariable$clone(deep = FALSE)deepWhether to make a deep clone.