This class represents a CF group in memory. It descends from
NCGroup and functions as such with the exception that it has no
associated CFResource and the handle field thus always returns NULL.
ncdfCF::NCObject -> ncdfCF::NCGroup -> MemoryGroup
friendlyClassName(read-only) A nice description of the class.
handleReturn NULL as a MemoryGroup has no resource.
Inherited methods
new()Create an instance of this class.
MemoryGroup$new(id, name, fullname, parent, title, history)idThe identifier of the group.
nameThe name of the group.
fullnameThe fully qualified name of the group.
parentThe parent group of this group. The parent of the root
group is NULL.
title, historyTitle and history attributes for the group.
clone()The objects of this class are cloneable with this method.
MemoryGroup$clone(deep = FALSE)deepWhether to make a deep clone.
This object descends from NCGroup and functions as such with the
exception that it has no associated CFResource and the handle field
thus always returns NULL.