This class represents an netCDF dimensions. It contains the information on a dimension that is stored in an netCDF file.
ncdfCF::NCObject -> NCDimension
lengthThe length of the dimension. If field unlim = TRUE, this
field indicates the length of the data in this dimension written to file.
unlimLogical flag to indicate if the dimension is unlimited, i.e. that additional data may be written to file incrementing in this dimension. Create a new netCDF dimension
This class should not be instantiated directly, create CF objects instead. This class is instantiated when opening a netCDF resource.
Inherited methods
new()NCDimension$new(id, name, length, unlim)idNumeric identifier of the netCDF dimension.
nameCharacter string with the name of the netCDF dimension.
lengthLength of the dimension.
unlimIs the dimension unlimited?
A NCDimension instance.
shard()Very concise information on the dimension
The information returned by this function is very concise and most useful when combined with similar information from other dimensions.
NCDimension$shard()Character string with very basic dimension information.
clone()The objects of this class are cloneable with this method.
NCDimension$clone(deep = FALSE)deepWhether to make a deep clone.
This class is not very useful for interactive use. Use the CFAxis descendent classes instead.