Learn R Programming

ncdfCF (version 0.2.1)

NCGroup: NetCDF group

Description

This class represents a netCDF group, the object that holds elements like dimensions and variables of a netCDF file. Additionally, the group also holds references to any CF objects based on the netCDF elements held by the group.

Arguments

Fields

resource

Access to the underlying netCDF resource.

fullname

The fully qualified absolute path of the group.

parent

Parent group of this group, NULL for the root group.

subgroups

List of child NCGroups of this group.

NCvars

List of netCDF variables that are located in this group.

NCdims

List of netCDF dimensions that are located in this group.

NCUDTs

List of netCDF user-defined types that are located in this group.

CFvars

List of CF data variables in this group. There must be a corresponding item in NCvars for each item in this list.

CFaxes

List of axes of CF data variables in this group. There must be a corresponding item in NCvars for each item in this list. Note that the CF data variable(s) that an axis is associated with may be located in a different group. Also, objects that further describe the basic axis definition, such as its bounds, labels, ancillary data, may be located in a different group; all such elements can be accessed directly from the CFAxis instances that this list holds.

CFaux

List of auxiliary variables. These could be CFAxisScalar or CFAuxiliaryLongLat that hold longitude and latitude values for every grid point in the data variable that references them.

Details

Direct access to groups is usually not necessary. The principal objects held by the group, CF data variables and axes, are accessible via other means. Only for access to the group attributes is a reference to a group required.