This class represents a netCDF group, the object that holds elements like dimensions and variables of a netCDF file. Additionally, the group also holds references to any CF objects based on the netCDF elements held by the group.
resourceAccess to the underlying netCDF resource.
fullnameThe fully qualified absolute path of the group.
parentParent group of this group, NULL for the root group.
subgroupsList of child NCGroups of this group.
NCvarsList of netCDF variables that are located in this group.
NCdimsList of netCDF dimensions that are located in this group.
NCUDTsList of netCDF user-defined types that are located in this group.
CFvarsList of CF data variables in this group. There must be a
corresponding item in NCvars for each item in this list.
CFaxesList of axes of CF data variables in this group. There must be
a corresponding item in NCvars for each item in this list. Note that the
CF data variable(s) that an axis is associated with may be located in a
different group. Also, objects that further describe the basic axis
definition, such as its bounds, labels, ancillary data, may be located in a
different group; all such elements can be accessed directly from the
CFAxis instances that this list holds.
CFauxList of auxiliary variables. These could be CFAxisScalar or CFAuxiliaryLongLat that hold longitude and latitude values for every grid point in the data variable that references them.
Direct access to groups is usually not necessary. The principal objects held by the group, CF data variables and axes, are accessible via other means. Only for access to the group attributes is a reference to a group required.