This class represents a netCDF variable, the object that holds the properties and data of elements like dimensions and variables of a netCDF file.
ncdfCF::NCObject -> NCVariable
groupNetCDF group where this variable is located.
vtypeThe netCDF data type of this variable.
ndimsNumber of dimensions that this variable uses.
dimidsVector of dimension identifiers that this variable uses. These are the so-called "NUG coordinate variables".
netcdf4Additional properties for a netcdf4 resource.
Create a new netCDF variable
This class should not be instantiated directly, they are created automatically when opening a netCDF resource.
CFList of CF objects that uses this netCDF variable.
fullname(read-only) Name of the NC variable including the group path from the root group.
Inherited methods
new()NCVariable$new(id, name, group, vtype, ndims, dimids)idNumeric identifier of the netCDF object.
nameCharacter string with the name of the netCDF object.
groupThe NCGroup this variable is located in.
vtypeThe netCDF data type of the variable.
ndimsThe number of dimensions this variable uses.
dimidsThe identifiers of the dimensions this variable uses.
An instance of this class.
shard()Very concise information on the variable
The information returned by this function is very concise and most useful when combined with similar information from other variables.
NCVariable$shard()Character string with very basic variable information.
clone()The objects of this class are cloneable with this method.
NCVariable$clone(deep = FALSE)deepWhether to make a deep clone.
Direct access to netCDF variables is usually not necessary. NetCDF variables are linked from CF data variables and axes and all relevant properties are thus made accessible.