dimlength: Lengths of dimensions of the data set or variable
Description
With this method the lengths of all dimensions of a dataset or a variable are
returned. Note that a dataset may have more dimensions than a variable from
the same dataset: other variables may use different dimensions.
Usage
# S4 method for ncdfVariable
dim(x)
# S4 method for ncdfDataset
dim(x)
Value
Named integer vector of dimension sizes of dimensions in x.