ncdfCF dimensionsThese are generic method definitions with implementations in descendant
classes. See ncdfDimensionNumeric, ncdfDimensionCharacter and
ncdfDimensionTime help topics for details.
has_bounds(x)axis(x)
has_bounds() returns a logical to indicate if bounds have been set
on the dimension. axis() returns a character to indicate which of axes "X",
"Y", "Z", or "T" is associated with the dimension, if any.
The ncdfCF dimension that the method operates on.