An ncdfDataset instance, or an error if the resource was not found
or errored upon reading.
Arguments
resource
The name of the NetCDF resource to open, either a local file
name or a remote URI.
keep_open
Logical flag to indicate if the NetCDF resource has to
remain open after reading the metadata. This should be enabled typically
only for programmatic access or when a remote resource has an expensive
access protocol (i.e. 2FA). The resource has to be explicitly closed with
close() after use. Note that when a dataset is opened with
keep_open = TRUE the resource may still be closed by the operating system
or the remote server.